@@ -12,39 +12,32 @@
 #define APPLICATION_H
 
 #include "ColorCode.h"
+#include "FuncCode.h"
 
 #include "support/strfwd.h"
 
-#include <boost/function.hpp>
+#include <functional>
 
 #include <vector>
 
 
 namespace lyx {
 
-class BufferView;
 class Buffer;
+class DispatchResult;
 class docstring_list;
 class FuncRequest;
 class FuncStatus;
 class Inset;
-class Lexer;
-struct RGBColor;
 
 namespace frontend {
 
-class Clipboard;
-class FontLoader;
-class Gui;
-class LyXView;
-class Selection;
-
 /// The main application class
 /**
 There should be only one instance of this class. No Qt object
-initialisation should be done before the instanciation of this class.
+initialisation should be done before the instantiation of this class.
 
- Model/View/Controller separation at frontend level in LyX-qt4:
+ Model/View/Controller separation at frontend level in qt frontend:
 
  BufferList (N Buffers)
    |
@@ -55,9 +48,9 @@ initialisation should be done before the instanciation of this class.
 
  Application (this is the frontend really, should probably be renamed).
    |
-   LyXView-1 (one or more in case of split-view mode).
+   GuiView-1 (one or more in case of split-view mode).
    |  |
-   |  <tab-widget-1-1> 
+   |  <tab-widget-1-1>
    |  |  |
    |  |  WorkArea-1-1-1 (M1-1 WorkAreas, M1-1 <= N)
    |  |  | |
@@ -71,9 +64,9 @@ initialisation should be done before the instanciation of this class.
    |  |  |   |
    |  |  |   Cursor
    |  |
-   |  <tab-widget-1-2> 
+   |  <tab-widget-1-2>
    |
-   LyXView-2 (one or more in case of split-view mode).
+   GuiView-2 (one or more in case of split-view mode).
    |  |
    |  <tab-widget-2-1>
    |  |  |
@@ -99,7 +92,7 @@ initialisation should be done before the instanciation of this class.
  screen using the Painter. There can be only one Buffer displayed in
  a BufferView and it is set on construction. Ideally, a BufferView
  should not be able to change the contents of its associated Buffer.
- A BufferView is instanciated and destroyed by a \c WorkArea; it is
+ A BufferView is instantiated and destroyed by a \c WorkArea; it is
  automatically destroyed by the parent WorkArea when its Buffer is
  closed.
 
@@ -115,7 +108,7 @@ initialisation should be done before the instanciation of this class.
  where the next Buffer insertion/deletion is going to take place.
 
 
- 3) The View: \c WorkArea (and it's qt4 specialisation GuiWorkArea)
+ 3) The View: \c WorkArea (and its qt specialisation GuiWorkArea)
 
  This contains the real screen area where the drawing is done by the
  Painter. One WorkArea holds one unique \c BufferView. While it could
@@ -132,14 +125,14 @@ initialisation should be done before the instanciation of this class.
  - etc.
 
 
- 4) The Window: \c LyXView (and its qt4 specialisation \c GuiView)
+ 4) The Window: \c GuiView
 
  This is a full window containing a menubar, toolbars and a central
- widget. A LyXView is in charge of creating and closing a View for a
+ widget. A GuiView is in charge of creating and closing a View for a
  given Buffer.
- In the qt4 specialisation, \c GuiView, the central widget is a tab
- widget. Each tab is reverved to the visualisation of one Buffer and
- contains one WorkArea. In the qt4 frontend, one LyXView thus contains
+ In the qt specialisation, \c GuiView, the central widget is a tab
+ widget. Each tab is reserved to the visualisation of one Buffer and
+ contains one WorkArea. In the qt frontend, one GuiView thus contains
  multiple WorkAreas but this number can limited to one for another
  frontend. The idea is that the kernel should not know how a Buffer
  is displayed on screen; it's the frontend business.
@@ -168,20 +161,24 @@ public:
 	///
 	virtual ~Application() {}
 
-	///
-	virtual bool getStatus(FuncRequest const & cmd, FuncStatus & flag) const = 0;
-	/// dispatch command.
-	/// \return true if the \c FuncRequest has been dispatched.
-	virtual bool dispatch(FuncRequest const & cmd) = 0;
+	/// LyX dispatcher: executes lyx actions and does necessary
+	/// screen updates depending on results.
+	/// This method encapsulates all the LyX command operations.
+	/// This is the class of the LyX's "high level event handler".
+	/// Every user command is processed here, either invocated from
+	/// keyboard or from the GUI. All GUI objects, including buttons and
+	/// menus should use this class and never call kernel functions directly.
+	virtual DispatchResult const & dispatch(FuncRequest const &) = 0;
+
+	/// LyX dispatcher: executes lyx actions and returns result.
+	virtual void dispatch(FuncRequest const &, DispatchResult & dr) = 0;
 
 	///
-	virtual void resetGui() = 0;
+	virtual FuncStatus getStatus(FuncRequest const & cmd) const = 0;
 
 	/// Load files and restore GUI Session.
 	virtual void restoreGuiSession() = 0;
 
-	///
-	virtual void hideDialogs(std::string const & name, Inset * inset) const = 0;
 	///
 	virtual Buffer const * updateInset(Inset const * inset) const = 0;
 
@@ -203,17 +200,24 @@ public:
 	* It returns false on failure and sets r, g, b to 0.
 	*/
 	virtual bool getRgbColor(ColorCode col, RGBColor & rgbcol) = 0;
+	/// Like getRgbColor(), but static and slower
+	static bool getRgbColorUncached(ColorCode col, RGBColor & rgbcol);
+
+	/**
+	 * @return true if LyX uses a dark theme
+	 */
+	virtual bool isInDarkMode() = 0;
 
 	/** Eg, passing Color_black returns "000000",
 	*      passing Color_white returns "ffffff".
 	*/
 	virtual std::string const hexName(ColorCode col) = 0;
-	
+
 	/**
 	* add a callback for socket read notification
 	* @param fd socket descriptor (file/socket/etc)
 	*/
-	typedef boost::function<void()> SocketCallback;
+	typedef std::function<void()> SocketCallback;
 	virtual void registerSocketCallback(int fd, SocketCallback func) = 0;
 
 	/**
@@ -225,8 +229,32 @@ public:
 	virtual bool searchMenu(FuncRequest const & func,
 		docstring_list & names) const = 0;
 
+	virtual bool hasBufferView() const = 0;
+
 	/// \return the icon file name for the given action.
-	virtual docstring iconName(FuncRequest const & f, bool unknown) = 0;
+	static docstring iconName(FuncRequest const & f, bool unknown);
+	/// \return the math icon name for the given command.
+	static docstring mathIcon(docstring const & c);
+
+	/// The language associated to current keyboard
+	virtual std::string inputLanguageCode() const = 0;
+	/// Handle a accented char key sequence
+	/// FIXME: this is only needed for LFUN_ACCENT_* in Text::dispatch()
+	virtual void handleKeyFunc(FuncCode action) = 0;
+
+	/// Start a long operation with some cancel possibility (button or ESC)
+	virtual void startLongOperation() = 0;
+	/// This needs to be periodically called to avoid freezing the GUI
+	virtual bool longOperationCancelled() = 0;
+	/// Stop the long operation mode (i.e., release the GUI)
+	virtual void stopLongOperation() = 0;
+	/// A started long operation is still in progress ?
+	virtual bool longOperationStarted() = 0;
+
+	// Add a buffer to the current view, do not switch to it.
+	virtual bool unhide(Buffer * buf) = 0;
+	// Apply preferences at the start
+	static void applyPrefs();
 };
 
 /// Return the list of loadable formats.
@@ -237,6 +265,8 @@ std::vector<std::string> loadableImageFormats();
 frontend::Application * theApp();
 frontend::Application * createApplication(int & argc, char * argv[]);
 void hideDialogs(std::string const & name, Inset * inset);
+/// Set locale correctly using LyXRC::gui_language
+void setLocale();
 
 } // namespace lyx
 
