@@ -17,7 +17,9 @@
 #ifndef GRAPHICSCONVERTER_H
 #define GRAPHICSCONVERTER_H
 
-#include <boost/signal.hpp>
+#include "support/signals.h"
+
+#include <memory>
 
 namespace lyx {
 
@@ -34,25 +36,24 @@ public:
 	/** One Converter per conversion ensures that the (hidden) signal
 	 *  is always connected to the expected slot.
 	 */
-	Converter(support::FileName const & from_file, std::string const & to_file_base,
+	Converter(support::FileName const & doc_fname,
+		  support::FileName const & from_file, std::string const & to_file_base,
 		  std::string const & from_format, std::string const & to_format);
 
-	/// Needed for the pimpl
-	~Converter();
-
 	/// We are explicit about when we begin the conversion process.
 	void startConversion() const;
 
 	/** Connect and you'll be informed when the conversion process has
 	 *  finished.
-	 *  If the conversion is succesful, then the listener is passed \c true.
+	 *  If the conversion is successful, then the listener is passed \c true.
+	 *  The connection is closed when this is destroyed.
 	 */
-	typedef boost::signal<void(bool)> sig_type;
+	typedef signal<void(bool)> sig_type;
 	typedef sig_type::slot_type slot_type;
 	///
-	boost::signals::connection connect(slot_type const &) const;
+	connection connect(slot_type const &) const;
 
-	/** If the conversion is succesful, this returns the name of the
+	/** If the conversion is successful, this returns the name of the
 	 *  resulting file.
 	 *  If conversion fails or has not been completed, however, it
 	 *  returns an empty string.
@@ -67,7 +68,7 @@ private:
 	/// Use the Pimpl idiom to hide the internals.
 	class Impl;
 	/// The pointer never changes although *pimpl_'s contents may.
-	Impl * const pimpl_;
+	std::shared_ptr<Impl> const pimpl_;
 };
 
 } // namespace graphics
